Revision: 201011 RCL_3
authorDremov Kirill (Nokia-D-MSW/Tampere) <kirill.dremov@nokia.com>
Wed, 31 Mar 2010 23:00:46 +0300
branchRCL_3
changeset 12 a005fc61b02a
parent 10 ece4bbb094df
child 13 bbcfd14ce6a7
Revision: 201011 Kit: 201013
devencdiskutils/DevEncCommonUtils/group/DevEncCommonUtils.mmp
devencdiskutils/DevEncCommonUtils/src/DevEncKeyUtils.cpp
gba/gbaserver/src/bootstrap.cpp
gba/sis/gba.sis
gba/sis/gba.sisx
pkiutilities/CertmanUi/INC/CertmanuiCommon.h
pkiutilities/CertmanUi/INC/CertmanuiKeeper.h
pkiutilities/CertmanUi/INC/CertmanuicontainerTrust.h
pkiutilities/CertmanUi/SRC/CertmanuiCertificateHelper.cpp
pkiutilities/CertmanUi/SRC/CertmanuiKeeper.cpp
pkiutilities/CertmanUi/SRC/CertmanuicontainerTrust.cpp
pkiutilities/CertmanUi/SRC/CertmanuiviewAuthority.cpp
pkiutilities/CertmanUi/SRC/CertmanuiviewTrust.cpp
remotelock/CenRep/keys_remotelock.xls
securitydialogs/Autolock/CenRep/keys_autolock.xls
securitydialogs/Autolock/CenRep/keys_lock.xls
securitydialogs/Autolock/src/AutolockAppUi.cpp
--- a/devencdiskutils/DevEncCommonUtils/group/DevEncCommonUtils.mmp	Mon Mar 15 12:43:21 2010 +0200
+++ b/devencdiskutils/DevEncCommonUtils/group/DevEncCommonUtils.mmp	Wed Mar 31 23:00:46 2010 +0300
@@ -51,7 +51,9 @@
 LIBRARY         pbe.lib
 LIBRARY         random.lib // for PKCS5
 LIBRARY         x509.lib // for PKCS5
-LIBRARY			imut.lib // for base64 coding
+LIBRARY         inetprotutil.lib // for base64 coding , was using imut.lib before 
+
+
 DEBUGLIBRARY    flogger.lib
 
 // EXPORTUNFROZEN
--- a/devencdiskutils/DevEncCommonUtils/src/DevEncKeyUtils.cpp	Mon Mar 15 12:43:21 2010 +0200
+++ b/devencdiskutils/DevEncCommonUtils/src/DevEncKeyUtils.cpp	Wed Mar 31 23:00:46 2010 +0300
@@ -24,13 +24,14 @@
 #include "DevEncLog.h"
 #include "DevEncUids.hrh"
 
+
 #include <pbe.h>
 #include <pbedata.h>
 //#include <PathInfo.h> // for system path literals
 #include <pkcs5kdf.h>
 #include <s32file.h>
 #include <s32mem.h>
-#include <imcvcodc.h>
+#include <tconvbase64.h>
 
 #include <DevEncEngineConstants.h>
 #include <DevEncEngineBase.h>
@@ -273,8 +274,7 @@
     aResult = HBufC8::NewL( resultPtr.Length()*4/3+3 );
     TPtr8 returnPtr = aResult->Des();
     returnPtr.SetLength( 0 );
-    TImCodecB64 b64codec;
-    b64codec.Initialise();
+    TBase64 b64codec;
     b64codec.Encode( *result, returnPtr );
     
     // Destroy the evidence
@@ -320,8 +320,7 @@
     HBufC8* decodedKey = HBufC8::NewLC( aPkcs5Key.Length()*3/4 );
     TPtr8 keyPtr = decodedKey->Des();
     keyPtr.SetLength( 0 );
-    TImCodecB64 b64codec;
-    b64codec.Initialise();
+    TBase64 b64codec;
     b64codec.Decode( aPkcs5Key, keyPtr );
 
     // Read the parameters and ciphertext from the input
--- a/gba/gbaserver/src/bootstrap.cpp	Mon Mar 15 12:43:21 2010 +0200
+++ b/gba/gbaserver/src/bootstrap.cpp	Wed Mar 31 23:00:46 2010 +0300
@@ -1039,7 +1039,8 @@
             }
         
         GBA_TRACE_DEBUG(("Cached IMPI = ")); 
-        GBA_TRACE_DEBUG(*tmpIdentity);
+        if(tmpIdentity != NULL)
+        	GBA_TRACE_DEBUG(*tmpIdentity);
         GBA_TRACE_DEBUG(("IMPI from smart card = ")); 
         GBA_TRACE_DEBUG(*iIdentity);
         
Binary file gba/sis/gba.sis has changed
Binary file gba/sis/gba.sisx has changed
--- a/pkiutilities/CertmanUi/INC/CertmanuiKeeper.h	Mon Mar 15 12:43:21 2010 +0200
+++ b/pkiutilities/CertmanUi/INC/CertmanuiKeeper.h	Wed Mar 31 23:00:46 2010 +0300
@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2009 Nokia Corporation and/or its subsidiary(-ies). 
+* Copyright (c) 2003-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 * This component and the accompanying materials are made available
 * under the terms of "Eclipse Public License v1.0"
@@ -195,11 +195,16 @@
         */
         TBool   iStartup;
 
-         /**
+        /**
         * Certificate helper class
         */
         CCertManUICertificateHelper*    iCertificateHelper;
 
+        /**
+        * Index for the current CA cert for changing trust settings
+        */
+        TInt iCurrentCACertForTrustSettings;
+
     private: // functions
 
         /**
--- a/pkiutilities/CertmanUi/INC/CertmanuicontainerTrust.h	Mon Mar 15 12:43:21 2010 +0200
+++ b/pkiutilities/CertmanUi/INC/CertmanuicontainerTrust.h	Wed Mar 31 23:00:46 2010 +0300
@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2010 Nokia Corporation and/or its subsidiary(-ies). 
+* Copyright (c) 2003-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 * This component and the accompanying materials are made available
 * under the terms of "Eclipse Public License v1.0"
@@ -240,6 +240,8 @@
         void ShowTrustChangeSettingPageL( const TUid aClientUid,
             TDesC& aClientName, CCTCertInfo& aEntry );
 
+        void ChangeTrustChangeSettingSingleClickL();
+
         void InsertItemToTrustListL( const TInt index, const TUid id,
                                    CCTCertInfo& entry, CDesCArray* itemArray,
                                    TInt position );
--- a/pkiutilities/CertmanUi/SRC/CertmanuiCertificateHelper.cpp	Mon Mar 15 12:43:21 2010 +0200
+++ b/pkiutilities/CertmanUi/SRC/CertmanuiCertificateHelper.cpp	Wed Mar 31 23:00:46 2010 +0300
@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2009 Nokia Corporation and/or its subsidiary(-ies). 
+* Copyright (c) 2003-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 * This component and the accompanying materials are made available
 * under the terms of "Eclipse Public License v1.0"
@@ -527,7 +527,6 @@
 // HBufC& aMessage, TPtrC aValue, TInt aResourceOne)
 // Reads dynamic text from CertManAPI, if the string is empty
 // put a not defined text from the resource in its place
-// KMaxLengthTextCertLabel = 510, used by CertLabel(), Issuer(), Owner()
 // ---------------------------------------------------------
 //
 void CCertManUICertificateHelper::DetailsDynamicL(
@@ -536,26 +535,29 @@
     CERTMANUILOGGER_ENTERFN(
         "CCertManUICertificateHelper::DetailsDynamicL" );
 
-    HBufC* buf = HBufC::NewLC( KMaxLengthTextCertLabel );
-    buf->Des() = aValue;
-    buf->Des().TrimLeft();
-    // Cut CertLabel after fourth semi colon
-    TPtrC trimmedCertLabel = CutCertificateField( buf->Des() );
-    buf->Des().Copy( trimmedCertLabel );
-    TInt length = buf->Des().Length();
-    if ( length == 0 )
+    HBufC* buf = aValue.AllocLC();
+    TPtr trimmedValue( buf->Des() );
+    trimmedValue.TrimLeft();
+
+    if( trimmedValue.Length() > KMaxLengthTextCertLabelVisible )
+        {
+        trimmedValue.SetLength( KMaxLengthTextCertLabelVisible - 1 );
+        trimmedValue.Append( KTextUtilClipEndChar );
+        }
+
+    if ( trimmedValue.Length() == 0 )
         {
         DetailsResourceL( aMessage, aResourceOne );
         }
     else
         {
-        //LRM (Left-to-Right mark 200E)
+        //LRM (Left-to-Right mark 0x200E)
         const TInt KLRMark = 0x200E;
-        aMessage.Des().Append( buf->Des() );
-        aMessage.Des().Append(KLRMark);
+        aMessage.Des().Append( trimmedValue );
+        aMessage.Des().Append( KLRMark );
         aMessage.Des().Append( KCertManUIDetailsViewEnter );
         }
-    CleanupStack::PopAndDestroy();  // buf
+    CleanupStack::PopAndDestroy( buf );
 
     CERTMANUILOGGER_LEAVEFN(
         "CCertManUICertificateHelper::DetailsDynamicL" );
--- a/pkiutilities/CertmanUi/SRC/CertmanuiKeeper.cpp	Mon Mar 15 12:43:21 2010 +0200
+++ b/pkiutilities/CertmanUi/SRC/CertmanuiKeeper.cpp	Wed Mar 31 23:00:46 2010 +0300
@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2009 Nokia Corporation and/or its subsidiary(-ies). 
+* Copyright (c) 2003-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 * This component and the accompanying materials are made available
 * under the terms of "Eclipse Public License v1.0"
@@ -170,7 +170,8 @@
 // Constructor with parent
 // ---------------------------------------------------------
 //
-CCertManUIKeeper::CCertManUIKeeper(): iResourceLoader( *iCoeEnv )
+CCertManUIKeeper::CCertManUIKeeper() : iCurrentCACertForTrustSettings( KErrNotFound ),
+        iResourceLoader( *iCoeEnv )
     {
     CERTMANUILOGGER_CREATE; //lint !e960
     CERTMANUILOGGER_WRITE_TIMESTAMP( "CCertManUIKeeper::CCertManUIKeeper" );
--- a/pkiutilities/CertmanUi/SRC/CertmanuicontainerTrust.cpp	Mon Mar 15 12:43:21 2010 +0200
+++ b/pkiutilities/CertmanUi/SRC/CertmanuicontainerTrust.cpp	Wed Mar 31 23:00:46 2010 +0300
@@ -170,10 +170,7 @@
     switch( aEventType )
         {
         case EEventItemSingleClicked:
-            if ( !iKeeper.iWrapper->IsActive() )
-                {
-                iParent.ChangeTrustL();
-                }
+            ChangeTrustChangeSettingSingleClickL();
             break;
         default:
             {
@@ -701,6 +698,33 @@
     }
 
 // ---------------------------------------------------------------------------
+// CCertManUIContainerTrust::ChangeTrustChangeSettingSingleClickL()
+// ---------------------------------------------------------------------------
+//
+void CCertManUIContainerTrust::ChangeTrustChangeSettingSingleClickL()
+    {
+    if( !iKeeper.iWrapper->IsActive() )
+        {
+        TInt certIndex = iKeeper.iCurrentCACertForTrustSettings;
+
+        if( certIndex >= 0 && certIndex < iKeeper.iCALabelEntries.Count() )
+            {
+            CCTCertInfo* entry = iKeeper.iCALabelEntries[ certIndex ]->iCAEntry;
+            if( entry && entry->IsDeletable() )
+                {
+                TInt currentTrustSetting = iListBox->CurrentItemIndex();
+                if( currentTrustSetting >= 0 && currentTrustSetting < iClientUids.Count() )
+                    {
+                    TUid uid = iClientUids[ currentTrustSetting ];
+                    ChangeTrustValueL( *entry, uid );
+                    UpdateTrustListboxItemL( *entry, currentTrustSetting );
+                    }
+                }
+            }
+        }
+    }
+
+// ---------------------------------------------------------------------------
 // CCertManUIContainerTrust::PopupTrustChangeSettingPageL(
 //      TInt aCertificateIndex)
 // Finds out which client was focused in Trust Settings view and calls
--- a/pkiutilities/CertmanUi/SRC/CertmanuiviewAuthority.cpp	Mon Mar 15 12:43:21 2010 +0200
+++ b/pkiutilities/CertmanUi/SRC/CertmanuiviewAuthority.cpp	Wed Mar 31 23:00:46 2010 +0300
@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2009 Nokia Corporation and/or its subsidiary(-ies). 
+* Copyright (c) 2003-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 * This component and the accompanying materials are made available
 * under the terms of "Eclipse Public License v1.0"
@@ -364,6 +364,7 @@
                 }
             CleanupStack::PopAndDestroy();  // buf
 
+            iKeeper.iCurrentCACertForTrustSettings = helpIndex3;
             ((CAknViewAppUi*)iAvkonAppUi)->ActivateLocalViewL(
                 KCertManUIViewTrustId, TUid::Uid( helpIndex3), KNullDesC8 );
             break;
--- a/pkiutilities/CertmanUi/SRC/CertmanuiviewTrust.cpp	Mon Mar 15 12:43:21 2010 +0200
+++ b/pkiutilities/CertmanUi/SRC/CertmanuiviewTrust.cpp	Wed Mar 31 23:00:46 2010 +0300
@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2007 Nokia Corporation and/or its subsidiary(-ies). 
+* Copyright (c) 2003-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 * This component and the accompanying materials are made available
 * under the terms of "Eclipse Public License v1.0"
@@ -302,6 +302,7 @@
         }
 
     RemoveNaviPane();
+    iKeeper.iCurrentCACertForTrustSettings = KErrNotFound;
 
     CERTMANUILOGGER_LEAVEFN( " CCertManUIViewTrust::DoDeactivate" );
     }
Binary file remotelock/CenRep/keys_remotelock.xls has changed
Binary file securitydialogs/Autolock/CenRep/keys_autolock.xls has changed
Binary file securitydialogs/Autolock/CenRep/keys_lock.xls has changed
--- a/securitydialogs/Autolock/src/AutolockAppUi.cpp	Mon Mar 15 12:43:21 2010 +0200
+++ b/securitydialogs/Autolock/src/AutolockAppUi.cpp	Wed Mar 31 23:00:46 2010 +0300
@@ -493,7 +493,7 @@
 			if(view)
 				{	
 		  		TRect aCallRect;
-				STATIC_CAST(CAutolockView*, view)->HandleCall(15, aCallRect);
+				STATIC_CAST(CAutolockView*, view)->HandleCall(0x15, aCallRect);
 				}
 		
 			}
@@ -516,6 +516,12 @@
         if (callState == EPSCTsyCallStateNone && simStatus != ESimNotPresent)
 			{	
 			// try put autolock back to foreground
+			CAknView* view = View(KAutoLockViewId);
+			if(view)
+				{	
+				TRect aCallRect;
+				STATIC_CAST(CAutolockView*, view)->HandleCall(0x19, aCallRect);
+				}
 			TApaTask self(iCoeEnv->WsSession());
 			self.SetWgId(iCoeEnv->RootWin().Identifier());
 			self.BringToForeground();		
@@ -528,7 +534,7 @@
 			if(view)
 				{	
 			  	TRect aCallRect;
-				STATIC_CAST(CAutolockView*, view)->HandleCall(16, aCallRect);
+				STATIC_CAST(CAutolockView*, view)->HandleCall(0x16, aCallRect);
 				}
 			}
 		}
@@ -744,6 +750,14 @@
             TRAPD(err,
 			{
 			iDeviceLockQueryStatus = ETrue;
+			TBool iAppKeyBelongedToBigClock=EFalse;
+			if(!iAppKey)
+				{
+				RDebug::Printf( "%s %s (%u) stealing EStdKeyApplication0 from BigClock=%x", __FILE__, __PRETTY_FUNCTION__, __LINE__, 0 );
+				RWindowGroup& groupWin=iCoeEnv->RootWin();
+				iAppKey = groupWin.CaptureKeyUpAndDowns(EStdKeyApplication0, 0, 0); // Capture app key now, in case that it was given to BigClock
+				iAppKeyBelongedToBigClock=ETrue;
+				}
 			if(handler->AskSecCodeInAutoLockL())
 				{		
 				iLocked = EFalse;
@@ -755,6 +769,13 @@
 				}
             else
 				{  // make sure that we will be topmost still
+					if(iAppKey && iAppKeyBelongedToBigClock)
+						{
+						RDebug::Printf( "%s %s (%u) giving EStdKeyApplication0 to BigClock=%x", __FILE__, __PRETTY_FUNCTION__, __LINE__, 0 );
+						RWindowGroup& groupWin=iCoeEnv->RootWin();
+						groupWin.CancelCaptureKeyUpAndDowns(iAppKey);	// give S60-Application key back to BigClock
+						iAppKey = 0;
+						}
 				    iDeviceLockQueryStatus = EFalse;
                     TInt callState;
                     RProperty::Get( KPSUidCtsyCallInformation, KCTsyCallState, callState );
@@ -941,7 +962,7 @@
 	if(view)
 	  {
 	  TRect aCallRect;
-      STATIC_CAST(CAutolockView*, view)->HandleCall(17, aCallRect);
+      STATIC_CAST(CAutolockView*, view)->HandleCall(0x17, aCallRect);
 	  STATIC_CAST(CAutolockView*, view)->MakeVisible(ETrue);
 	  }
 	else
@@ -1275,7 +1296,7 @@
 								    {	
 								        STATIC_CAST(CAutolockView*, view)->ScreenDeviceChanged();
 								    	TRect aCallRect;
-								        STATIC_CAST(CAutolockView*, view)->HandleCall(1, aCallRect);
+								        STATIC_CAST(CAutolockView*, view)->HandleCall(0x1, aCallRect);
    								    	if(aCallButtonRect.iBr.iX==0)
    								    		aCallButtonRect = TRect (aCallRect);
 								    }
@@ -1357,7 +1378,7 @@
 								  if(view)
 								    {	
 								    	TRect aCallRect;
-								        STATIC_CAST(CAutolockView*, view)->HandleCall(10, aCallRect);
+								        STATIC_CAST(CAutolockView*, view)->HandleCall(0x10, aCallRect);
 												if(aCallButtonRect.iBr.iX==0)
    								    		aCallButtonRect = TRect (aCallRect);
 								    }
--- a/pkiutilities/CertmanUi/INC/CertmanuiCommon.h	Mon Mar 15 12:43:21 2010 +0200
+++ b/pkiutilities/CertmanUi/INC/CertmanuiCommon.h	Wed Mar 31 23:00:46 2010 +0300
@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2007 Nokia Corporation and/or its subsidiary(-ies). 
+* Copyright (c) 2003-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 * This component and the accompanying materials are made available
 * under the terms of "Eclipse Public License v1.0"
@@ -73,8 +73,8 @@
 const TInt KMaxLengthTextDateString = 11;
 // HH0
 const TInt KMaxLengthTextSerialNumberFormatting = 3;
-// CertLabel, Issuer, Owner max length 510 bytes
-const TInt KMaxLengthTextCertLabel = 510;
+// CertLabel, Issuer, Owner max length 1024 bytes
+const TInt KMaxLengthTextCertLabel = 1024;
 // CertLabel, Issuer, Owner max visible length
 const TInt KMaxLengthTextCertLabelVisible = 200;
 // CertWimLabel, KeyLabel, KeyWimLabel max length 255 bytes